@@ -1,9 +1,9 @@
  /* ================================================================== *
   * FILE: tclreadline.c
-  * $Id: e1d64b5f9164e56a9d05a4c13ac76f87646dfa4d $
+  * $Id: a81d2fca2303840fd4166b846c1babe8740f9f23 $
   * ---
   * tclreadline -- gnu readline for tcl
-  * http://www.zellner.org/tclreadline/
+  * https://github.com/flightaware/tclreadline/
   * Copyright (c) 1998 - 2014, Johannes Zellner <johannes@zellner.org>
   * This software is copyright under the BSD license.
   * ================================================================== */
@@ -563,6 +563,9 @@ int
 Tclreadline_Init(Tcl_Interp *interp)
 {
     int status;
+ #ifdef USE_TCL_STUBS
+     Tcl_InitStubs(interp, "8.6", 0);
+#endif
     Tcl_CreateObjCommand(interp, "::tclreadline::readline", TclReadlineCmd,
         (ClientData) NULL, (Tcl_CmdDeleteProc *) NULL);
     tclrl_interp = interp;
